# -*- coding: utf-8 -*-
#
# Copyright 2010, LoCo Directory Project,
#                 Adnane Belmadiaf
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from launchpadlib.launchpad import Launchpad
from launchpadlib.errors import HTTPError
from launchpadlib.launchpad import EDGE_SERVICE_ROOT

from django.conf import settings

import os
import sys

def is_debug_user(username):
    try:
        if settings.DEBUG and username in settings.DEBUG_USERS:
            return True
    except AttributeError:
        return False
    return False

def lp_login(lp_instance=EDGE_SERVICE_ROOT):
    cachedir = os.path.join(settings.PROJECT_PATH, 'lp_data/cache')
    client_ident = getattr(settings, 'LP_PROJECT_NAME', "LoCo Team Directory")
    try:
        launchpad = Launchpad.login_anonymously(client_ident, lp_instance, cachedir)
    except:
        try:
            # Support for launchpadlib pre 1.5.4.
            launchpad = Launchpad.login(client_ident, "", "", lp_instance, cachedir)
        except:
            # Launchpad might be offline.
            return None
    return launchpad

def get_mugshot_url(lp, identity):
    # Not ideal, but until LP #336943
    # or similar, we are in a hard spot.
    # When this bug is fixed, this can be made cleaner.
    try:
        lp.people[identity].mugshot.open()
        return "https://edge.launchpad.net/api/beta/~%s/mugshot" % (identity)
    except HTTPError:
        # 404 or some other issue that means we should default to False
        return "https://edge.launchpad.net/api/beta/ubuntu/mugshot"

def get_user_timezone(username, lp=None):
    timezone = 'UTC'
    if username is None:
        return timezone
    
    if not lp: 
        lp = lp_login()
        if not lp:
            return timezone
    try: 
        lp_user = lp.people[username]
        timezone = lp_user.timezone
    except:
        pass
    return timezone
