#
# Copyright 2010, LoCo Directory Project.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from django.db import models
from django.contrib.auth import models as auth_models
# Create your models here.

class UserProfile(models.Model):
    " Store profile information about a user "

    user = models.OneToOneField(auth_models.User)
    realname = models.CharField("Real Name", max_length=150, blank=True)
    website = models.URLField(max_length=255, blank=True, null=True)
    """ not used
    tz = models.CharField(verbose_name=_('Timezone'), max_length=32, default='UTC')
    blog = models.URLField(verbose_name=_('Blog URL'), blank=True, null=True, verify_exists=False)
    twitter = models.CharField(verbose_name=_('Twitter ID'), max_length=32, blank=True, null=True)
    identica = models.CharField(verbose_name=_('Identi.ca ID'), max_length=32, blank=True, null=True)
    picasa = models.CharField(verbose_name=_('Picasa ID'), max_length=32, blank=True, null=True)
    flickr = models.CharField(verbose_name=_('Flickr ID'), max_length=32, blank=True, null=True)
    facebook = models.CharField(verbose_name=_('Facebook ID'), max_length=32, blank=True, null=True)
    irc = models.CharField(verbose_name=_('IRC Nick'), max_length=32, blank=True, null=True)
    aim = models.CharField(verbose_name=_('AOL IM Nick'), max_length=32, blank=True, null=True)
    xmpp = models.CharField(verbose_name=_('XMPP IM Nick'), max_length=32, blank=True, null=True)
    """
    def __unicode__(self):
        try:
            if self.realname:
                return "%s (%s)" % (self.user.username, self.realname)
            return "%s" % self.user.username
        except:
            return "Unknown Profile"
    
def _getUserProfile(self):
    if not self.is_authenticated():
        return UserProfile()
    
    profile, created = UserProfile.objects.get_or_create(user=self)
    
    if created:
        from common.launchpad import get_user_timezone
        #profile.tz = get_user_timezone(self.username)
        profile.save()
        
    return profile

def _getAnonProfile(self):
    return UserProfile()
        
auth_models.User.profile = property(_getUserProfile)
auth_models.AnonymousUser.profile = property(_getAnonProfile)

def create_profile(username):
    user, created = auth_models.User.objects.get_or_create(username=username)
    if created:
        user.save()
    profile, created = UserProfile.objects.get_or_create(user=user)
    if created:
        # set real name as username for now, 
        # we get the name later on via cronjob
        profile.realname = username
        profile.save()
    return profile
